1.0.0[−][src]Trait libcore_drone::hash::Hash
A hashable type.
Types implementing Hash are able to be hashed with an instance of
Hasher.
Implementing Hash
You can derive Hash with #[derive(Hash)] if all fields implement Hash.
The resulting hash will be the combination of the values from calling
hash on each field.
#[derive(Hash)] struct Rustacean { name: String, country: String, }
If you need more control over how a value is hashed, you can of course
implement the Hash trait yourself:
use std::hash::{Hash, Hasher}; struct Person { id: u32, name: String, phone: u64, } impl Hash for Person { fn hash<H: Hasher>(&self, state: &mut H) { self.id.hash(state); self.phone.hash(state); } }
Hash and Eq
When implementing both Hash and Eq, it is important that the following
property holds:
k1 == k2 -> hash(k1) == hash(k2)
In other words, if two keys are equal, their hashes must also be equal.
HashMap and HashSet both rely on this behavior.
Thankfully, you won't need to worry about upholding this property when
deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].
Required methods
Loading content...Provided methods
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
H: Hasher,
Implementations on Foreign Types
impl<Y, R> Hash for FiberState<Y, R> where
R: Hash,
Y: Hash, [src]
R: Hash,
Y: Hash,
impl Hash for CString[src]
impl Hash for CStr[src]
impl<A> Hash for VecDeque<A> where
A: Hash, [src]
A: Hash,
impl<T> Hash for Arc<T> where
T: Hash + ?Sized, [src]
T: Hash + ?Sized,
impl<T> Hash for BTreeSet<T> where
T: Hash, [src]
T: Hash,
impl Hash for String[src]
impl<K, V> Hash for BTreeMap<K, V> where
K: Hash,
V: Hash, [src]
K: Hash,
V: Hash,
impl<T> Hash for LinkedList<T> where
T: Hash, [src]
T: Hash,
impl<T> Hash for Box<T> where
T: Hash + ?Sized, [src]
T: Hash + ?Sized,
impl<T> Hash for Vec<T> where
T: Hash, [src]
T: Hash,
impl<'_, B> Hash for Cow<'_, B> where
B: Hash + ToOwned + ?Sized, [src]
B: Hash + ToOwned + ?Sized,
impl<T> Hash for Rc<T> where
T: Hash + ?Sized, [src]
Loading content...
T: Hash + ?Sized,
Implementors
impl Hash for ![src]
impl Hash for ()[src]
impl Hash for libcore_drone::cmp::Ordering[src]
impl Hash for libcore_drone::sync::atomic::Ordering[src]
impl Hash for TypeId[src]
impl Hash for Error[src]
impl Hash for PhantomPinned[src]
impl Hash for NonZeroI128[src]
impl Hash for NonZeroI16[src]
impl Hash for NonZeroI32[src]
impl Hash for NonZeroI64[src]
impl Hash for NonZeroI8[src]
impl Hash for NonZeroIsize[src]
impl Hash for NonZeroU128[src]
impl Hash for NonZeroU16[src]
impl Hash for NonZeroU32[src]
impl Hash for NonZeroU64[src]
impl Hash for NonZeroU8[src]
impl Hash for NonZeroUsize[src]
impl Hash for RangeFull[src]
impl Hash for NoneError[src]
impl Hash for Duration[src]
impl Hash for bool[src]
impl Hash for char[src]
impl Hash for i8[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[i8], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl Hash for i16[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[i16], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl Hash for i32[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[i32], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl Hash for i64[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[i64], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl Hash for i128[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[i128], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl Hash for isize[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[isize], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl Hash for str[src]
impl Hash for u8[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[u8], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl Hash for u16[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[u16], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl Hash for u32[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[u32], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl Hash for u64[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[u64], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl Hash for u128[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[u128], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl Hash for usize[src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
H: Hasher,
fn hash_slice<H>(data: &[usize], state: &mut H) where
H: Hasher, [src]
H: Hasher,
impl<'_, T> Hash for &'_ T where
T: Hash + ?Sized, [src]
T: Hash + ?Sized,
impl<'_, T> Hash for &'_ mut T where
T: Hash + ?Sized, [src]
T: Hash + ?Sized,
impl<A> Hash for (A,) where
A: Hash + ?Sized, [src]
A: Hash + ?Sized,
impl<A, B> Hash for (A, B) where
A: Hash,
B: Hash + ?Sized, [src]
A: Hash,
B: Hash + ?Sized,
impl<A, B, C> Hash for (A, B, C) where
A: Hash,
B: Hash,
C: Hash + ?Sized, [src]
A: Hash,
B: Hash,
C: Hash + ?Sized,
impl<A, B, C, D> Hash for (A, B, C, D) where
A: Hash,
B: Hash,
C: Hash,
D: Hash + ?Sized, [src]
A: Hash,
B: Hash,
C: Hash,
D: Hash + ?Sized,
impl<A, B, C, D, E> Hash for (A, B, C, D, E) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash + ?Sized, [src]
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash + ?Sized,
impl<A, B, C, D, E, F> Hash for (A, B, C, D, E, F) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash + ?Sized, [src]
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash + ?Sized,
impl<A, B, C, D, E, F, G> Hash for (A, B, C, D, E, F, G) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash + ?Sized, [src]
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash + ?Sized,
impl<A, B, C, D, E, F, G, H> Hash for (A, B, C, D, E, F, G, H) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash + ?Sized, [src]
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash + ?Sized,
impl<A, B, C, D, E, F, G, H, I> Hash for (A, B, C, D, E, F, G, H, I) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash + ?Sized, [src]
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash + ?Sized,
impl<A, B, C, D, E, F, G, H, I, J> Hash for (A, B, C, D, E, F, G, H, I, J) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash,
J: Hash + ?Sized, [src]
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash,
J: Hash + ?Sized,
impl<A, B, C, D, E, F, G, H, I, J, K> Hash for (A, B, C, D, E, F, G, H, I, J, K) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash,
J: Hash,
K: Hash + ?Sized, [src]
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash,
J: Hash,
K: Hash + ?Sized,
impl<A, B, C, D, E, F, G, H, I, J, K, L> Hash for (A, B, C, D, E, F, G, H, I, J, K, L) where
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash,
J: Hash,
K: Hash,
L: Hash + ?Sized, [src]
A: Hash,
B: Hash,
C: Hash,
D: Hash,
E: Hash,
F: Hash,
G: Hash,
H: Hash,
I: Hash,
J: Hash,
K: Hash,
L: Hash + ?Sized,
impl<Idx> Hash for Range<Idx> where
Idx: Hash, [src]
Idx: Hash,
impl<Idx> Hash for RangeFrom<Idx> where
Idx: Hash, [src]
Idx: Hash,
impl<Idx> Hash for RangeInclusive<Idx> where
Idx: Hash, [src]
Idx: Hash,
impl<Idx> Hash for RangeTo<Idx> where
Idx: Hash, [src]
Idx: Hash,
impl<Idx> Hash for RangeToInclusive<Idx> where
Idx: Hash, [src]
Idx: Hash,
impl<P> Hash for Pin<P> where
P: Hash, [src]
P: Hash,
impl<Ret> Hash for extern "C" fn() -> Ret[src]
impl<Ret> Hash for fn() -> Ret[src]
impl<Ret> Hash for unsafe extern "C" fn() -> Ret[src]
impl<Ret> Hash for unsafe fn() -> Ret[src]
impl<Ret, A> Hash for extern "C" fn(A) -> Ret[src]
impl<Ret, A> Hash for extern "C" fn(A, ...) -> Ret[src]
impl<Ret, A> Hash for fn(A) -> Ret[src]
impl<Ret, A> Hash for unsafe extern "C" fn(A) -> Ret[src]
impl<Ret, A> Hash for unsafe extern "C" fn(A, ...) -> Ret[src]
impl<Ret, A> Hash for unsafe fn(A) -> Ret[src]
impl<Ret, A, B> Hash for extern "C" fn(A, B) -> Ret[src]
impl<Ret, A, B> Hash for extern "C" fn(A, B, ...) -> Ret[src]
impl<Ret, A, B> Hash for fn(A, B) -> Ret[src]
impl<Ret, A, B> Hash for unsafe extern "C" fn(A, B) -> Ret[src]
impl<Ret, A, B> Hash for unsafe extern "C" fn(A, B, ...) -> Ret[src]
impl<Ret, A, B> Hash for unsafe fn(A, B) -> Ret[src]
impl<Ret, A, B, C> Hash for extern "C" fn(A, B, C) -> Ret[src]
impl<Ret, A, B, C> Hash for extern "C" fn(A, B, C, ...) -> Ret[src]
impl<Ret, A, B, C> Hash for fn(A, B, C) -> Ret[src]
impl<Ret, A, B, C> Hash for unsafe extern "C" fn(A, B, C) -> Ret[src]
impl<Ret, A, B, C> Hash for unsafe extern "C" fn(A, B, C, ...) -> Ret[src]
impl<Ret, A, B, C> Hash for unsafe fn(A, B, C) -> Ret[src]
impl<Ret, A, B, C, D> Hash for extern "C" fn(A, B, C, D) -> Ret[src]
impl<Ret, A, B, C, D> Hash for extern "C" fn(A, B, C, D, ...) -> Ret[src]
impl<Ret, A, B, C, D> Hash for fn(A, B, C, D) -> Ret[src]
impl<Ret, A, B, C, D> Hash for unsafe extern "C" fn(A, B, C, D) -> Ret[src]
impl<Ret, A, B, C, D> Hash for unsafe extern "C" fn(A, B, C, D, ...) -> Ret[src]
impl<Ret, A, B, C, D> Hash for unsafe fn(A, B, C, D) -> Ret[src]
impl<Ret, A, B, C, D, E> Hash for extern "C" fn(A, B, C, D, E) -> Ret[src]
impl<Ret, A, B, C, D, E> Hash for extern "C" fn(A, B, C, D, E, ...) -> Ret[src]
impl<Ret, A, B, C, D, E> Hash for fn(A, B, C, D, E) -> Ret[src]
impl<Ret, A, B, C, D, E> Hash for unsafe extern "C" fn(A, B, C, D, E) -> Ret[src]
impl<Ret, A, B, C, D, E> Hash for unsafe extern "C" fn(A, B, C, D, E, ...) -> Ret[src]
impl<Ret, A, B, C, D, E> Hash for unsafe fn(A, B, C, D, E) -> Ret[src]
impl<Ret, A, B, C, D, E, F> Hash for extern "C" fn(A, B, C, D, E, F) -> Ret[src]
impl<Ret, A, B, C, D, E, F> Hash for extern "C" fn(A, B, C, D, E, F, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F> Hash for fn(A, B, C, D, E, F) -> Ret[src]
impl<Ret, A, B, C, D, E, F> Hash for unsafe extern "C" fn(A, B, C, D, E, F) -> Ret[src]
impl<Ret, A, B, C, D, E, F> Hash for unsafe extern "C" fn(A, B, C, D, E, F, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F> Hash for unsafe fn(A, B, C, D, E, F) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G> Hash for extern "C" fn(A, B, C, D, E, F, G) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G> Hash for extern "C" fn(A, B, C, D, E, F, G, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G> Hash for fn(A, B, C, D, E, F, G) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G> Hash for unsafe fn(A, B, C, D, E, F, G) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H> Hash for extern "C" fn(A, B, C, D, E, F, G, H) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H> Hash for extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H> Hash for fn(A, B, C, D, E, F, G, H) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H> Hash for unsafe fn(A, B, C, D, E, F, G, H) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I> Hash for fn(A, B, C, D, E, F, G, H, I) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I> Hash for unsafe fn(A, B, C, D, E, F, G, H, I) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for fn(A, B, C, D, E, F, G, H, I, J) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J> Hash for unsafe fn(A, B, C, D, E, F, G, H, I, J) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K> Hash for unsafe fn(A, B, C, D, E, F, G, H, I, J, K) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for unsafe extern "C" fn(A, B, C, D, E, F, G, H, I, J, K, L, ...) -> Ret[src]
impl<Ret, A, B, C, D, E, F, G, H, I, J, K, L> Hash for unsafe fn(A, B, C, D, E, F, G, H, I, J, K, L) -> Ret[src]
impl<T> Hash for *const T where
T: ?Sized, [src]
T: ?Sized,
impl<T> Hash for *mut T where
T: ?Sized, [src]
T: ?Sized,
impl<T> Hash for Bound<T> where
T: Hash, [src]
T: Hash,
impl<T> Hash for Option<T> where
T: Hash, [src]
T: Hash,
impl<T> Hash for Poll<T> where
T: Hash, [src]
T: Hash,
impl<T> Hash for Reverse<T> where
T: Hash, [src]
T: Hash,
impl<T> Hash for PhantomData<T> where
T: ?Sized, [src]
T: ?Sized,
impl<T> Hash for Discriminant<T>[src]
impl<T> Hash for ManuallyDrop<T> where
T: Hash + ?Sized, [src]
T: Hash + ?Sized,
impl<T> Hash for Wrapping<T> where
T: Hash, [src]
T: Hash,
impl<T> Hash for NonNull<T> where
T: ?Sized, [src]
T: ?Sized,
impl<T> Hash for [T] where
T: Hash, [src]
T: Hash,
impl<T, E> Hash for Result<T, E> where
E: Hash,
T: Hash, [src]
E: Hash,
T: Hash,
impl<Y, R> Hash for GeneratorState<Y, R> where
R: Hash,
Y: Hash, [src]
R: Hash,
Y: Hash,
impl<const N: usize, T> Hash for [T; N] where
T: Hash,
[T; N]: LengthAtMost32, [src]
T: Hash,
[T; N]: LengthAtMost32,