[−][src]Crate libcore_drone
A libcore wrapper to enable native async/await syntax for Drone
applications.
Usage
Place the following to the Cargo.toml:
[dependencies]
core = { package = "libcore-drone", version = "0.11.0" }
Description
This crate re-exports contents of core and defines two new functions
with the following paths:
core::future::from_generatorcore::future::poll_with_tls_context
These two functions are absent from original libcore, but defined in libstd.
This is the reason for the following errors when you attempt to use .await
in no_std context:
error[E0433]: failed to resolve: could not find `poll_with_tls_context` in `future`
error[E0433]: failed to resolve: could not find `from_generator` in `future`
Modules
| alloc | Memory allocation APIs |
| any | This module implements the |
| arch | SIMD and vendor intrinsics module. |
| array | Implementations of things like |
| ascii | Operations on ASCII strings and characters. |
| borrow | A module for working with borrowed data. |
| cell | Shareable mutable containers. |
| char | A character type. |
| clone | The |
| cmp | Functionality for ordering and comparison. |
| convert | Traits for conversions between types. |
| default | The |
| f32 | This module provides constants which are specific to the implementation
of the |
| f64 | This module provides constants which are specific to the implementation
of the |
| ffi | Utilities related to FFI bindings. |
| fmt | Utilities for formatting and printing strings. |
| future | Asynchronous values. |
| future | Asynchronous values. |
| hash | Generic hashing support. |
| hint | Hints to compiler that affects how code should be emitted or optimized. |
| i8 | The 8-bit signed integer type. |
| i16 | The 16-bit signed integer type. |
| i32 | The 32-bit signed integer type. |
| i64 | The 64-bit signed integer type. |
| i128 | The 128-bit signed integer type. |
| isize | The pointer-sized signed integer type. |
| iter | Composable external iteration. |
| marker | Primitive traits and types representing basic properties of types. |
| mem | Basic functions for dealing with memory. |
| num | Numeric traits and functions for the built-in numeric types. |
| ops | Overloadable operators. |
| option | Optional values. |
| pin | Types that pin data to its location in memory. |
| prelude | The libcore prelude |
| ptr | Manually manage memory through raw pointers. |
| result | Error handling with the |
| slice | Slice management and manipulation. |
| str | String manipulation. |
| sync | Synchronization primitives |
| task | Types and Traits for working with asynchronous tasks. |
| time | Temporal quantification. |
| u8 | The 8-bit unsigned integer type. |
| u16 | The 16-bit unsigned integer type. |
| u32 | The 32-bit unsigned integer type. |
| u64 | The 64-bit unsigned integer type. |
| u128 | The 128-bit unsigned integer type. |
| usize | The pointer-sized unsigned integer type. |
| intrinsics | Experimental Compiler intrinsics. |
| panic | Experimental Panic support in the standard library. |
| panicking | Experimental Panic support for libcore |
| raw | Experimental Contains struct definitions for the layout of compiler built-in types. |
| unicode | Experimental |
Macros
| assert_eq | Asserts that two expressions are equal to each other (using |
| assert_ne | Asserts that two expressions are not equal to each other (using |
| debug_assert | Asserts that a boolean expression is |
| debug_assert_eq | Asserts that two expressions are equal to each other. |
| debug_assert_ne | Asserts that two expressions are not equal to each other. |
| panic | Panics the current thread. |
| todo | Indicates unfinished code. |
| try | Deprecated Unwraps a result or propagates its error. |
| unimplemented | Indicates unfinished code by panicking with a message of "not yet implemented". |
| unreachable | Indicates unreachable code. |
| write | Writes formatted data into a buffer. |
| writeln | Write formatted data into a buffer, with a newline appended. |
| matches | Experimental Returns whether the given expression matches any of the given patterns. |